eepy - modules for a Python course
=====================================

eepy is a collection of Python modules and programs which are intended to be used at a Python course in Sungkyunkwan University.
Over half of the codes came from introcs package by Dr. Walker M. White under MIT license, and we greatly appeciate his package for being released under open source license.

* eepy at PYPI : <https://pypi.org/project/eepy/>
* eepy at github : <https://github.com/hbmin/eepy>

Installation
============

To install eepy from PyPI, run:

    $ pip install eepy

Then you can import eepy to use modules/classes in eepy, or you can use pycat:

    >>> import eepy

    or,

    $ pycat [options] file1 [file2 [file3 ...]]

For full usage instructions, help(eepy) at Python prompt or run:

    >>> help(eepy)

    or,

    $ pycat -h


Changes and Additions
=====================

The modifications in this package are minor fixes and cosmetic changes to introcs package by Dr. Walker M. White, and some more modules for this Python course are added.

* art.py   : classes for the Python course which came from introcs
* point.py : classes Point3 and Point2 from introcs.
* cat.py   : command-line tool similar to UNIX cat command.
* test.py  : helper functions for unit testing of homeworks.
* zoo.py   : helpful small functions used in the Python course.


Acknowledgements
================

Thanks to Dr. Walker M. White for open-sourcing his introcs.

* introcs : <https://pypi.org/project/introcs/>
